/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctHTMLExport.cpp
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

/*------------------------------------------------------------- Includes */

#include "ctHTMLExport.h"

#include <qstring.h>
#include <qtextstream.h>

/*------------------------------------------------------------ Functions */

/** Writes the HTML header, containing the title of the page,
to the TextStream \a t.
@param t Reference to the QTextStream
@param sTitle Reference to the title of the page
*/
void writeHTMLHeader(QTextStream &t, const QString &sTitle, bool bUseTTFont)
{
  // Write start of header
  t << "<HTML>\n<HEAD>\n";

  if (bUseTTFont == true)
  {
    t << "<STYLE TYPE=\"text/css\">" << endl;
    t << "SPAN { font-family: \"DBChess\", serif }" << endl;
    t << "</STYLE>" << endl;
  }

  t << "<TITLE>" << endl;

  // Write title
  t << sTitle << endl;

  // Write end of header
  t << "</TITLE>\n</HEAD>" << endl << endl;
  t << "<BODY BGCOLOR=FFFFFF>" << endl << endl;
}  

/** Writes the HTML trailer, containing the ChessTask logo,
to the TextStream \a t.
@param t Reference to the QTextStream
@param graphicsDir The graphics directory
*/
void writeHTMLTrailer(QTextStream &t, const QString &graphicsDir, bool bUseTTFont)
{
  // Write trailer
  t << "<DIV ALIGN=RIGHT>";

  if (bUseTTFont == true)
  {
    t << "<A HREF=\"http://chesstask.sourceforge.net/getfont.html\">";
    t << "<IMG SRC=\"" << graphicsDir;
    t << "getfont.png\" ALT=\"Get DBChess font\"";
    t << " TITLE=\"Get DBChess font\" BORDER=0></A>";
  }

  t << "<A HREF=\"http://chesstask.sourceforge.net\">";
  t << "<IMG SRC=\"" << graphicsDir;
  t << "ctasks.png\" ALT=\"ChessTask Homepage\"";
  t << " TITLE=\"ChessTask Homepage\" BORDER=0></A></DIV>" << endl;

  t << "</BODY>\n</HTML>" << endl << endl;
}  

