/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctPosition.h
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

#ifndef CT_POSITION_H
#define CT_POSITION_H

/*------------------------------------------------------------- Includes */

#include <qobject.h>
#include <qtextstream.h>

/*------------------------------------------- Forward class declarations */

class QString;

/*-------------------------------------------------------------- Classes */

/** This class \a ctPosition contains all relevant data for a board
position and provides several functions for the import and export
from/to various data formats.
*/
class ctPosition: public QObject
{
    Q_OBJECT

public:
    ctPosition();
    ctPosition(const ctPosition &elem);
    ctPosition &operator= (const ctPosition &elem);
    
    unsigned int &operator() (unsigned row, unsigned col);
    unsigned int operator() (unsigned row, unsigned col) const;                                      

    void load(QTextStream &t);
    void save(QTextStream &t);
    
    void importFEN(const QString &fenString);

    void exportFEN(QTextStream &t);
    void exportMarkerLines(QTextStream &t);
    void exportLaTeX(QTextStream &t);
    void exportHTML(QTextStream &t, const QString &graphicsDir);

    void clearBoard();
    void initBoard();

protected:

private:    
    /** Position */
    unsigned int Position[64];

    void writeLine(QTextStream &t, int iLine);
};

#endif

