/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctProgressDialog.cpp
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

/*------------------------------------------------------------- Includes */

#include "ctProgressDialog.h"

#include <qlayout.h>
#include <qprogressbar.h>
#include <qlabel.h>

/*------------------------------------------------------------ Functions */

/** Constructor for the \a ctProgressDialog class. */
ctProgressDialog::ctProgressDialog( QWidget *parent, QString name )
    : QDialog( parent, name, false)
    
{
    QBoxLayout *vb = new QVBoxLayout( this );
    
    pbProgress = new QProgressBar(this, "pbProgress");

    vb->addWidget(pbProgress);
    vb->activate();

    resize(200, minimumHeight());
}

/*---------------------------------------------------------------- Slots */

/** Resets the progress bar.
*/
void ctProgressDialog::slotResetProgressBar()
{
  pbProgress->reset();
}

/** Sets the total (=maximum) number of
steps for the progress bar.
@param iSteps The number of total steps
*/
void ctProgressDialog::slotSetTotalProgressSteps(int iSteps)
{
  pbProgress->setTotalSteps(iSteps);
}

/** Sets the current number of
steps for the progress bar.
@param iCurrentProgress The number of current steps
*/
void ctProgressDialog::slotSetCurrentProgress(int iCurrentProgress)
{
  pbProgress->setProgress(iCurrentProgress);
}

