/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctString.h
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

#ifndef CT_STRING_H
#define CT_STRING_H

/*------------------------------------------------------------- Includes */

#include <qstring.h>

/*------------------------------------------- Forward class declarations */

class QRegExp;

/*-------------------------------------------------------------- Classes */

/** This class \a ctString ``specializes'' the class \a QString
and provides a new constructor that converts the given string
to either LaTeX or HTML format. Also, the function 
\a findMatchingBracket is available. It is used to find matching
bracket pairs.
*/
class ctString: public QString
{

public:
    ctString(const QString &, 
             int iType,
	     const QString &graphicsDir = QString::null,
	     bool bExpand = false,
	     bool bUseTTFont = false);

    int findMatchingBrace(int startPos);

protected:

private:    
    void convertToHTML(const QString &graphicsDir, 
                       bool bExpand,
                       bool bUseTTFont);
    void convertToLaTeX();
    void convertFromOldFormat();
    void processInformatorSymbols(const QString &graphicsDir, 
                                  bool bExpand,
                                  bool bUseTTFont);
    void processMoveEnvironments(bool bUseTTFont);
    void replaceMoveSymbol(int from,
                           int *to,
                           const QRegExp &regExp, 
			   const QString &plainText,
                           bool bUseTTFont,
                           const QString &spanText,
                           bool bEscape);
#ifndef QTVER2X
    int getCapturedCommand(QRegExp &rx);
#endif
    void processTextEnvironments();
    void replaceInformatorSymbol(const QString &baseName, 
				 const QString &description,
				 const QString &graphicsDir,
				 bool bExpand,
                                 bool bUseTTFont,
                                 const QString &ttfReplace);
    void replacePlainSymbol(const QString &baseName, 
			    const QString &plainText,
                            bool bUseTTFont,
                            const QString &spanText);

};

#endif

